@@ -10,6 +10,7 @@ import logging
 log = logging.getLogger("modules.N800")
 
 import conduit
+import conduit.datatypes.File as File
 import conduit.datatypes.Video as Video
 import conduit.datatypes.Audio as Audio
 import conduit.datatypes.Photo as Photo
@@ -59,11 +60,14 @@ class N800Base(FileDataProvider.FolderTwoWay):
     #Signifies that a conversion should not take place
     NO_CONVERSION_STRING = _("unchanged")
 
+    _configurable_ = True
+
     def __init__(self, mount, udi, folder):
         FileDataProvider.FolderTwoWay.__init__(self,
                             "file://"+folder,
                             "N800",
                             False,
+                            False,
                             False
                             )
         self.mount = mount
@@ -91,9 +95,10 @@ class N800Base(FileDataProvider.FolderTwoWay):
         dialog.run()
 
     def refresh(self):
-        if not Vfs.uri_exists(self.folder):
+        d = File.File(URI=self.folder)
+        if not d.exists():
             try:
-                Vfs.uri_make_directory_and_parents(self.folder)
+                d.make_directory_and_parents()
             except:
                 raise Exceptions.RefreshError("Error Creating Directory")
         FileDataProvider.FolderTwoWay.refresh(self)
@@ -185,7 +190,7 @@ class N800PhotoTwoWay(N800Base):
     """
 
     _name_ = _("N800 Photos")
-    _description_ = _("Synchronizes video to a N800 device")
+    _description_ = _("Synchronizes photo to a N800 device")
     _in_type_ = "file/photo"
     _out_type_ = "file/photo"
     _icon_ = "image-x-generic"
